@@ -713,7 +713,7 @@ class AjaxFKWidgetCellsRender(template.Node):
         obj = self.vobj.resolve(context)
         list_display = self.vfields.resolve(context)
 
-        context[self.var_result] = [{'name': f, 'value': getattr(obj, f, None)} for f in list_display]
+        context[self.var_result] = [{'name': f, 'value': context['driver']._get_field_value(f, obj)} for f in list_display]
 
         return ''
 
