@@ -83,6 +83,12 @@ class AjaxFKWidget(TextInput):
     def render(self, name, value, attrs=None):
         attrs = attrs or {}
         attrs['class'] = attrs.get('class', '') + ' ajax-fk'
+        
+        # Implement max length
+        try:    
+            attrs['maxlength'] = self.rel.get_related_field().max_length
+        except AttributeError:
+            pass
 
         # Renders using inherited class
         ret = super(AjaxFKWidget, self).render(name, value, attrs)
